==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/MaskInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { MaskInputBase } from "./MaskInputBase";
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
export let MaskInput = /*@__PURE__*/ (() => {
    class MaskInput extends MaskInputBase {
        get ae() {
            let ret_ = this.f.m("valueMode");
            ret_ = enumGetBox(MaskInputValueMode_$type, EnumUtil.getEnumValue(MaskInputValueMode_$type, this.f.f(MaskInputValueMode_$type, ret_)));
            return EnumUtil.getEnumValue(MaskInputValueMode_$type, ret_);
        }
        set ae(a) {
            let value_ = enumGetBox(MaskInputValueMode_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("valueMode", value_);
        }
        get ag() {
            let ret_ = this.f.m("value");
            return ret_;
        }
        set ag(a) {
            let value_ = a;
            this.f.u("value", value_);
        }
        get af() {
            let ret_ = this.f.m("mask");
            return ret_;
        }
        set af(a) {
            let value_ = a;
            this.f.u("mask", value_);
        }
        ai() {
            this.nativeElement.reportValidity();
        }
        ah() {
            this.nativeElement.checkValidity();
        }
    }
    MaskInput.$t = /*@__PURE__*/ markType(MaskInput, 'MaskInput', MaskInputBase.$);
    return MaskInput;
})();

==> igniteui-react-18.5.2-beta.0.tgz: package/esm2015/lib/MaskInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { MaskInputBase } from "./MaskInputBase";
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
/**
 * @hidden
 */
export let MaskInput = /*@__PURE__*/ (() => {
    class MaskInput extends MaskInputBase {
        get af() {
            let ret_ = this.f.n("valueMode");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(MaskInputValueMode_$type, EnumUtil.getEnumValue(MaskInputValueMode_$type, this.f.f(MaskInputValueMode_$type, ret_)));
            return EnumUtil.getEnumValue(MaskInputValueMode_$type, ret_);
        }
        set af(a) {
            let value_ = enumGetBox(MaskInputValueMode_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.v("valueMode", value_);
        }
        get ah() {
            let ret_ = this.f.n("value");
            return ret_;
        }
        set ah(a) {
            let value_ = a;
            this.f.v("value", value_);
        }
        get ag() {
            let ret_ = this.f.n("mask");
            return ret_;
        }
        set ag(a) {
            let value_ = a;
            this.f.v("mask", value_);
        }
        ai() {
            this.nativeElement.connectedCallback();
        }
    }
    MaskInput.$t = /*@__PURE__*/ markType(MaskInput, 'MaskInput', MaskInputBase.$);
    return MaskInput;
})();
